@@ -21,15 +21,16 @@ function  #function to identify outdated or Excel-mogrified gene symbols
         x <- as.character(x)
         warning("coercing x to character.")
     }
-    if(!is(hgnc.table, "data.frame") | !identical(colnames(hgnc.table), c("Symbol", "Approved.Symbol"))){
-        rm(hgnc.table)
+    if(is.null(hgnc.table)){
         data("hgnc.table", package="HGNChelper", envir=environment())
+    }else if(!is(hgnc.table, "data.frame") | !identical(colnames(hgnc.table), c("Symbol", "Approved.Symbol"))){
+        stop("If hgnc.table is specified, it must be a dataframe with two columns named 'Symbol' and 'Approved.Symbol'")
     }
     approved <- x %in% hgnc.table$Approved.Symbol
     ##change to upper case, then change orfs back to lower case:
     x.casecorrected <- toupper(x)
     x.casecorrected <- sub("(.*C[0-9XY]+)ORF(.+)", "\\1orf\\2", x.casecorrected)
-    if (!all(x == x.casecorrected))
+    if (!identical(all.equal(x, x.casecorrected), TRUE))
         warning("Some lower-case letters were found and converted to upper-case.
                  HGNChelper is intended for human symbols only, which should be all
                  upper-case except for open reading frames (orf).")
@@ -37,16 +38,17 @@ function  #function to identify outdated or Excel-mogrified gene symbols
     df <- data.frame(x=x,
                      Approved=approved,
                      Suggested.Symbol=sapply(1:length(x), function(i)
-                     ifelse(approved[i], x[i], ifelse(alias[i],paste(hgnc.table$Approved.Symbol[x.casecorrected[i] == hgnc.table$Symbol], 
-                     collapse=" /// "), NA))),
+                         ifelse(approved[i], x[i], ifelse(alias[i], paste(hgnc.table$Approved.Symbol[x.casecorrected[i] == hgnc.table$Symbol], collapse=" /// "), NA))),
                      stringsAsFactors=FALSE)
+
+
+    df$Approved[is.na(df$x)] <- FALSE
     if(!unmapped.as.na){
         df[is.na(df$Suggested.Symbol), "Suggested.Symbol"] <- df[is.na(df$Suggested.Symbol), "x"]
     }
-    if (sum(df$Approved) != nrow(df)) 
+    if (sum(df$Approved) != nrow(df))
         warning("x contains non-approved gene symbols")
-
     return(df)
 ### The function will return a data.frame of the same number of rows as the input,
-### with corrections possible from hgnc.table. 
+### with corrections possible from hgnc.table.
 }
